# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator 2.3.33.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class Run(Model):
    """The definition of a Run.

    :param run_number:
    :type run_number: int
    :param root_run_id:
    :type root_run_id: str
    :param experiment_id: The Id of the experiment that created this run.
    :type experiment_id: str
    :param created_utc: The time the run was created in UTC.
    :type created_utc: datetime
    :param created_by: The details of the user who created the run.
    :type created_by: ~_restclient.models.User
    :param user_id: The Id of the user that created the run.
    :type user_id: str
    :param token: A token used for authenticating a run.
    :type token: str
    :param token_expiry_time_utc: The Token expiration time in UTC.
    :type token_expiry_time_utc: datetime
    :param error: If an error occurred during the run, this will be populated.
    :type error: ~_restclient.models.ErrorResponse
    :param warnings: A list of warnings that occurred during the run.
    :type warnings: list[~_restclient.models.RunDetailsWarning]
    :param revision:
    :type revision: long
    :param run_uuid: A system generated Id for the run
    :type run_uuid: str
    :param parent_run_uuid: A system generated Id for the run's parent
    :type parent_run_uuid: str
    :param root_run_uuid: A system generated Id for the root of the run's
     hierarchy
    :type root_run_uuid: str
    :param run_id: The identifier for the run. Run IDs must be less than 256
     characters and contain only alphanumeric characters with dashes and
     underscores.
    :type run_id: str
    :param parent_run_id: The parent of the run if the run is hierarchical;
     otherwise, Null.
    :type parent_run_id: str
    :param status: The status of the run. The Status string value maps to the
     RunStatus Enum.
    :type status: str
    :param start_time_utc: The start time of the run in UTC.
    :type start_time_utc: datetime
    :param end_time_utc: The end time of the run in UTC.
    :type end_time_utc: datetime
    :param options:
    :type options: ~_restclient.models.RunOptions
    :param name:
    :type name: str
    :param data_container_id:
    :type data_container_id: str
    :param description:
    :type description: str
    :param hidden:
    :type hidden: bool
    :param run_type:
    :type run_type: str
    :param properties:
    :type properties: dict[str, str]
    :param script_name:
    :type script_name: str
    :param target:
    :type target: str
    :param unique_child_run_compute_targets:
    :type unique_child_run_compute_targets: list[str]
    :param tags:
    :type tags: dict[str, str]
    :param input_datasets:
    :type input_datasets: list[~_restclient.models.DatasetLineage]
    :param output_datasets:
    :type output_datasets: list[~_restclient.models.OutputDatasetLineage]
    :param run_definition:
    :type run_definition: object
    :param created_from:
    :type created_from: ~_restclient.models.CreatedFrom
    :param cancel_uri:
    :type cancel_uri: str
    :param complete_uri:
    :type complete_uri: str
    :param diagnostics_uri:
    :type diagnostics_uri: str
    :param compute_request:
    :type compute_request: ~_restclient.models.ComputeRequest
    :param retain_for_lifetime_of_workspace:
    :type retain_for_lifetime_of_workspace: bool
    :param queueing_info:
    :type queueing_info: ~_restclient.models.QueueingInfo
    """

    _validation = {
        'unique_child_run_compute_targets': {'unique': True},
        'input_datasets': {'unique': True},
        'output_datasets': {'unique': True},
    }

    _attribute_map = {
        'run_number': {'key': 'runNumber', 'type': 'int'},
        'root_run_id': {'key': 'rootRunId', 'type': 'str'},
        'experiment_id': {'key': 'experimentId', 'type': 'str'},
        'created_utc': {'key': 'createdUtc', 'type': 'iso-8601'},
        'created_by': {'key': 'createdBy', 'type': 'User'},
        'user_id': {'key': 'userId', 'type': 'str'},
        'token': {'key': 'token', 'type': 'str'},
        'token_expiry_time_utc': {'key': 'tokenExpiryTimeUtc', 'type': 'iso-8601'},
        'error': {'key': 'error', 'type': 'ErrorResponse'},
        'warnings': {'key': 'warnings', 'type': '[RunDetailsWarning]'},
        'revision': {'key': 'revision', 'type': 'long'},
        'run_uuid': {'key': 'runUuid', 'type': 'str'},
        'parent_run_uuid': {'key': 'parentRunUuid', 'type': 'str'},
        'root_run_uuid': {'key': 'rootRunUuid', 'type': 'str'},
        'run_id': {'key': 'runId', 'type': 'str'},
        'parent_run_id': {'key': 'parentRunId', 'type': 'str'},
        'status': {'key': 'status', 'type': 'str'},
        'start_time_utc': {'key': 'startTimeUtc', 'type': 'iso-8601'},
        'end_time_utc': {'key': 'endTimeUtc', 'type': 'iso-8601'},
        'options': {'key': 'options', 'type': 'RunOptions'},
        'name': {'key': 'name', 'type': 'str'},
        'data_container_id': {'key': 'dataContainerId', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'hidden': {'key': 'hidden', 'type': 'bool'},
        'run_type': {'key': 'runType', 'type': 'str'},
        'properties': {'key': 'properties', 'type': '{str}'},
        'script_name': {'key': 'scriptName', 'type': 'str'},
        'target': {'key': 'target', 'type': 'str'},
        'unique_child_run_compute_targets': {'key': 'uniqueChildRunComputeTargets', 'type': '[str]'},
        'tags': {'key': 'tags', 'type': '{str}'},
        'input_datasets': {'key': 'inputDatasets', 'type': '[DatasetLineage]'},
        'output_datasets': {'key': 'outputDatasets', 'type': '[OutputDatasetLineage]'},
        'run_definition': {'key': 'runDefinition', 'type': 'object'},
        'created_from': {'key': 'createdFrom', 'type': 'CreatedFrom'},
        'cancel_uri': {'key': 'cancelUri', 'type': 'str'},
        'complete_uri': {'key': 'completeUri', 'type': 'str'},
        'diagnostics_uri': {'key': 'diagnosticsUri', 'type': 'str'},
        'compute_request': {'key': 'computeRequest', 'type': 'ComputeRequest'},
        'retain_for_lifetime_of_workspace': {'key': 'retainForLifetimeOfWorkspace', 'type': 'bool'},
        'queueing_info': {'key': 'queueingInfo', 'type': 'QueueingInfo'},
    }

    def __init__(self, run_number=None, root_run_id=None, experiment_id=None, created_utc=None, created_by=None, user_id=None, token=None, token_expiry_time_utc=None, error=None, warnings=None, revision=None, run_uuid=None, parent_run_uuid=None, root_run_uuid=None, run_id=None, parent_run_id=None, status=None, start_time_utc=None, end_time_utc=None, options=None, name=None, data_container_id=None, description=None, hidden=None, run_type=None, properties=None, script_name=None, target=None, unique_child_run_compute_targets=None, tags=None, input_datasets=None, output_datasets=None, run_definition=None, created_from=None, cancel_uri=None, complete_uri=None, diagnostics_uri=None, compute_request=None, retain_for_lifetime_of_workspace=None, queueing_info=None):
        super(Run, self).__init__()
        self.run_number = run_number
        self.root_run_id = root_run_id
        self.experiment_id = experiment_id
        self.created_utc = created_utc
        self.created_by = created_by
        self.user_id = user_id
        self.token = token
        self.token_expiry_time_utc = token_expiry_time_utc
        self.error = error
        self.warnings = warnings
        self.revision = revision
        self.run_uuid = run_uuid
        self.parent_run_uuid = parent_run_uuid
        self.root_run_uuid = root_run_uuid
        self.run_id = run_id
        self.parent_run_id = parent_run_id
        self.status = status
        self.start_time_utc = start_time_utc
        self.end_time_utc = end_time_utc
        self.options = options
        self.name = name
        self.data_container_id = data_container_id
        self.description = description
        self.hidden = hidden
        self.run_type = run_type
        self.properties = properties
        self.script_name = script_name
        self.target = target
        self.unique_child_run_compute_targets = unique_child_run_compute_targets
        self.tags = tags
        self.input_datasets = input_datasets
        self.output_datasets = output_datasets
        self.run_definition = run_definition
        self.created_from = created_from
        self.cancel_uri = cancel_uri
        self.complete_uri = complete_uri
        self.diagnostics_uri = diagnostics_uri
        self.compute_request = compute_request
        self.retain_for_lifetime_of_workspace = retain_for_lifetime_of_workspace
        self.queueing_info = queueing_info
